@@ -19,7 +19,7 @@ extern void do_init (const char *font, int cpi, int code_page, int draft,
 extern void do_fin (void);
 extern void fin_string (const char **string, int *len);
 extern void do_hskip (int pos);
-extern void init_font (int lflag, int x2flag, int x4flag);
+extern void init_font (int lflag, int x2flag, int x4flag, int code_page);
 extern void send_quoted (uchar c);
 extern void bold_on (void);
 extern void bold_off (void);
